==> cobaya-3.0.4.tar.gz: cobaya-3.0.4/cobaya/likelihoods/base_classes/InstallableLikelihood.py <==
r"""
.. module:: InstallableLikelihood

:Synopsis: Prototype class adding class methods for simple installation of likelihood data.
:Author: Jesus Torrado and Antony Lewis

"""

# Global
import os
import logging

# Local
from cobaya.likelihood import Likelihood


class InstallableLikelihood(Likelihood):
    install_options = {}

    @classmethod
    def get_install_options(cls):
        return cls.install_options

    @classmethod
    def get_path(cls, path):
        opts = cls.get_install_options()
        repo = opts.get("github_repository", None)
        if repo:
            data_path = repo.split('/')[-1]
        else:
            data_path = opts.get("data_path", cls.__name__)
        return os.path.realpath(os.path.join(path, "data", data_path))

    @classmethod
    def is_installed(cls, **kwargs):
        log = logging.getLogger(cls.__name__)
        if kwargs.get("data", True):
            path = kwargs["path"]
            opts = cls.get_install_options()
            if not opts:
                return True
            elif not (os.path.exists(path) and len(os.listdir(path)) > 0):
                log.error("The given installation path does not exist: '%s'", path)
                return False
        return True

    @classmethod
    def install(cls, path=None, force=False, code=False, data=True,
                no_progress_bars=False):
        if not data:
            return True
        log = logging.getLogger(cls.get_qualified_class_name())
        opts = cls.get_install_options()
        if not opts:
            log.info("No install options. Nothing to do.")
            return True
        repo = opts.get("github_repository", None)
        if repo:
            from cobaya.install import download_github_release
            log.info("Downloading %s data..." % repo)
            return download_github_release(
                os.path.join(path, "data"), repo, opts.get("github_release", "master"),
                no_progress_bars=no_progress_bars, logger=log)
        else:
            full_path = cls.get_path(path)
            if not os.path.exists(full_path):
                os.makedirs(full_path)
            if not data:
                return True
            url = opts["download_url"]
            log.info("Downloading likelihood data file: %s...", url)
            from cobaya.install import download_file
            if not download_file(url, full_path, decompress=True, logger=log,
                                 no_progress_bars=no_progress_bars):
                return False
            log.info("Likelihood data downloaded and uncompressed correctly.")
            return True

==> cobaya-3.1.0.tar.gz: cobaya-3.1.0/cobaya/likelihoods/base_classes/InstallableLikelihood.py <==
r"""
.. module:: InstallableLikelihood

:Synopsis: Prototype class adding class methods for simple installation of likelihood data.
:Author: Jesus Torrado and Antony Lewis

"""

# Global
import os

# Local
from cobaya.likelihood import Likelihood
from cobaya.typing import InfoDict
from cobaya.log import get_logger


class InstallableLikelihood(Likelihood):
    install_options: InfoDict = {}

    @classmethod
    def get_install_options(cls):
        return cls.install_options

    @classmethod
    def get_path(cls, path):
        opts = cls.get_install_options()
        repo = opts.get("github_repository", None)
        if repo:
            data_path = repo.split('/')[-1]
        else:
            data_path = opts.get("data_path", cls.__name__)
        return os.path.realpath(os.path.join(path, "data", data_path))

    @classmethod
    def is_installed(cls, **kwargs):
        if kwargs.get("data", True):
            path = kwargs["path"]
            opts = cls.get_install_options()
            if not opts:
                return True
            elif not (os.path.exists(path) and len(os.listdir(path)) > 0):
                log = get_logger(cls.get_qualified_class_name())
                func = log.info if kwargs.get("check", True) else log.error
                func("The given installation path does not exist: '%s'", path)
                return False
        return True

    @classmethod
    def install(cls, path=None, data=True, no_progress_bars=False, **_kwargs):
        if not data:
            return True
        log = get_logger(cls.get_qualified_class_name())
        opts = cls.get_install_options()
        if not opts:
            log.info("No install options. Nothing to do.")
            return True
        repo = opts.get("github_repository", None)
        if repo:
            from cobaya.install import download_github_release
            log.info("Downloading %s data..." % repo)
            return download_github_release(
                os.path.join(path, "data"), repo, opts.get("github_release", "master"),
                no_progress_bars=no_progress_bars, logger=log)
        else:
            full_path = cls.get_path(path)
            if not os.path.exists(full_path):
                os.makedirs(full_path)
            if not data:
                return True
            url = opts["download_url"]
            log.info("Downloading likelihood data file: %s...", url)
            from cobaya.install import download_file
            if not download_file(url, full_path, decompress=True, logger=log,
                                 no_progress_bars=no_progress_bars):
                return False
            log.info("Likelihood data downloaded and uncompressed correctly.")
            return True
